@@ -30,6 +30,7 @@ The data we collect is limited to:
 """
 
 import datetime
+import http.client as httplib
 import posthog
 import yaml
 import os
@@ -38,7 +39,6 @@ import sys
 import uuid
 from ploomber.telemetry import validate_inputs
 from ploomber import __version__
-import urllib.request
 import platform
 
 TELEMETRY_VERSION = '0.2'
@@ -53,15 +53,18 @@ def python_version():
     return f"{py_version.major}.{py_version.minor}.{py_version.micro}"
 
 
-# Check if host is online
-def is_online(host='http://ploomber.io'):
+def is_online():
+    """Check if host is online
+    """
+    conn = httplib.HTTPSConnection('www.google.com', timeout=1)
+
     try:
-        urllib.request.urlopen(host)
+        conn.request("HEAD", "/")
         return True
-    except urllib.error.HTTPError:
-        return False
-    except urllib.error.URLError:
+    except Exception:
         return False
+    finally:
+        conn.close()
 
 
 # Will output if the code is within a container
